Learn R Programming

mccmeiv (version 2.1)

mccmeiv-package: mccmeiv

Description

This package implements the methodology found in Manuel et al. to estimate parameters of a logistic model using data from a matched case control design with a mismeasured exposure variable with the help of instrumental variables.

Arguments

References

Manuel, CM, Sinha, S and Wang, S. Matched case-control data with a misclassified exposure: What can be done with instrumental variables? (Submitted).